@@ -10,15 +10,16 @@ classifiers = [
  
 setup(
   name='Kittyscript',
-  version='2.8.5',
+  version='2.9.5',
   description='Assist mode for python',
-  long_description=open('README.txt').read() + '\n\n' + open('CHANGELOG.txt').read(),
-  url='',  
+  long_description=open('README.md').read() + '\n\n' + open('CHANGELOG.txt').read(),
+  url='https://github.com/Iwertyuiop123653/kitty-script-',  
   author='Anahad Khosa',
   author_email='hahacoolguystaco@gmail.com',
   license='MIT', 
   classifiers=classifiers,
   keywords='Assist mode', 
   packages=find_packages(),
-  install_requires=[''] 
+  install_requires=['keyboard', 'qrcode', 'hashlib'],
+  long_description_content_type='text/markdown'
 )
\ No newline at end of file
